// 
// example of Monte Carlo simulation method
//
// evaluate \pi 
//

#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <time.h>

#define M_PI 3.1415926

#define NEXP 100000000	// max number of experiments

// generate random number <0..1)
inline double Random()
{
    return rand() / (RAND_MAX + 1.0);   // rand() can return RAND_MAX
}

int main()
{
    long N = 100;		// for print only
    long S = 0;
    clock_t start = clock();
    srand(time(0));             // set random seed
    for (int i = 0; i <= NEXP; i++) {
	double x = Random();
	double y = Random();
	if ((x * x + y * y) < 1.0)
	    S++;
	if (i == N) {		// print results
	    double pi = 4.0 * (double) S / i;
	    printf("pi = %8.6f err = %7.4f%% i = %ld \n", pi, (pi - M_PI)/M_PI*100, i);
	    N *= 10;
	}
    }
    printf("Time: %.2f s\n", (double)(clock()-start)/CLOCKS_PER_SEC);
}

